@@ -265,8 +265,10 @@ void mutt_parse_content_type (char *s, BODY *ct)
       pc++;
     ct->parameter = parse_parameters(pc);
 
-    /* Some pre-RFC1521 gateways still use the "name=filename" convention */
-    if ((pc = mutt_get_parameter("name", ct->parameter)) != 0)
+    /* Some pre-RFC1521 gateways still use the "name=filename" convention,
+     * but if a filename has already been set in the content-disposition,
+     * let that take precedence, and don't set it here */
+    if ((pc = mutt_get_parameter("name", ct->parameter)) != 0 && !ct->filename)
       ct->filename = safe_strdup(pc);
   }
   
@@ -471,7 +473,7 @@ BODY *mutt_parse_messageRFC822 (FILE *fp, BODY *parent)
 
   parent->hdr = mutt_new_header ();
   parent->hdr->offset = ftell (fp);
-  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr, 0);
+  parent->hdr->env = mutt_read_rfc822_header (fp, parent->hdr, 0, 0);
   msg = parent->hdr->content;
 
   /* ignore the length given in the content-length since it could be wrong
@@ -850,11 +852,16 @@ void mutt_parse_mime_message (CONTEXT *ctx, HEADER *cur)
  *
  * hdr		header structure of current message (optional).
  * 
- * user_hdrs	If set, store user headers.  Used for edit-message and 
+ * user_hdrs	If set, store user headers.  Used for recall-message and
  * 		postpone modes.
  * 
+ * weed		If this parameter is set and the user has activated the
+ * 		$weed option, honor the header weed list for user headers.
+ * 	        Used for recall-message.
+ * 
  */
-ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
+ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs,
+				   short weed)
 {
   ENVELOPE *e = mutt_new_envelope();
   LIST *last = NULL;
@@ -1175,6 +1182,13 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
      /* Keep track of the user-defined headers */
     if (!matched && user_hdrs)
     {
+      /* restore the original line */
+      line[strlen (line)] = ':';
+
+      if (weed && option (OPTWEED) && mutt_matches_ignore (line, Ignore)
+	  && !mutt_matches_ignore (line, UnIgnore))
+	continue;
+
       if (last)
       {
 	last->next = mutt_new_list ();
@@ -1182,7 +1196,6 @@ ENVELOPE *mutt_read_rfc822_header (FILE *f, HEADER *hdr, short user_hdrs)
       }
       else
 	last = e->userhdrs = mutt_new_list ();
-      line[strlen (line)] = ':';
       last->data = safe_strdup (line);
     }
 
