@@ -842,7 +842,7 @@ static void reply_attachment_list (int op, int tag, HEADER *hdr, BODY *body)
     char buffer [LONG_STRING];
 
     mutt_message ("Preparing to forward...");
-    if (mutt_prepare_edit_message (ctx, newhdr, hn) < 0)
+    if (mutt_prepare_template (ctx, newhdr, hn, 0) < 0)
     {
       mutt_clear_error();
       mutt_free_header (&newhdr);
@@ -936,10 +936,12 @@ mutt_attach_display_loop (MUTTMENU *menu, int op, FILE *fp, ATTACHPTR **idx)
 }
 
 
+static const char *Function_not_permitted = N_("Function not permitted in attach-message mode.");
+
 #define CHECK_ATTACH if(option(OPTATTACHMSG)) \
 		     {\
 			mutt_flushinp (); \
-			mutt_error ("Function not permitted in attach-message mode."); \
+			mutt_error _(Function_not_permitted); \
 			break; \
 		     }
 
